@@ -33,6 +33,9 @@
 #include "accessibility-keyboard.h"
 
 #ifdef HAVE_X11_EXTENSIONS_XKB_H
+#  ifdef __sun
+#    include <X11/Xlib.h>
+#  endif
 #  include <X11/XKBlib.h>
 #  include <X11/extensions/XKBstr.h>
 #  include <gdk/gdk.h>
@@ -70,7 +73,7 @@ dialog_response (GtkWidget *widget,
 	case GTK_RESPONSE_HELP:
 		capplet_help (GTK_WINDOW (widget),
 			      "wgoscustaccess.xml",
-			      "goscustaccess-2");
+			      "goscustaccess-6");
 		break;
 	case GTK_RESPONSE_DELETE_EVENT:
 	case GTK_RESPONSE_CLOSE:
@@ -106,6 +109,7 @@ main (int argc, char **argv)
 	g_signal_connect (G_OBJECT (dialog),
 		"response",
 		G_CALLBACK (dialog_response), changeset);
+	capplet_set_icon (dialog, "accessibility-keyboard-capplet.png");
 	gtk_widget_show_all (dialog);
 	gtk_main ();
 
