@@ -39,20 +39,23 @@
 #include "capplet-util.h"
 #include "gconf-property-editor.h"
 
-#define DEFAULT_APPS_KEY_BROWSER_NEEDS_TERM "/desktop/gnome/url-handlers/unknown/need-terminal"
-#define DEFAULT_APPS_KEY_BROWSER_EXEC       "/desktop/gnome/url-handlers/unknown/command"
 
-#define DEFAULT_APPS_KEY_HELP_VIEWER_NEEDS_TERM "/desktop/gnome/applications/help_viewer/needs_term"
-#define DEFAULT_APPS_KEY_HELP_VIEWER_ACCEPTS_URLS "/desktop/gnome/applications/help_viewer/accepts_urls"
-#define DEFAULT_APPS_KEY_HELP_VIEWER_EXEC "/desktop/gnome/applications/help_viewer/exec"
+#define DEFAULT_APPS_KEY_BROWSER_PATH "/desktop/gnome/url-handlers/http"
+#define DEFAULT_APPS_KEY_BROWSER_NEEDS_TERM DEFAULT_APPS_KEY_BROWSER_PATH"/needs_terminal"
+#define DEFAULT_APPS_KEY_BROWSER_EXEC       DEFAULT_APPS_KEY_BROWSER_PATH"/command"
 
-#define DEFAULT_APPS_KEY_TERMINAL_EXEC_ARG "/desktop/gnome/applications/terminal/exec_arg"
-#define DEFAULT_APPS_KEY_TERMINAL_EXEC "/desktop/gnome/applications/terminal/exec"
+#define DEFAULT_APPS_KEY_MAILER_PATH "/desktop/gnome/url-handlers/mailto"
+#define DEFAULT_APPS_KEY_MAILER_NEEDS_TERM DEFAULT_APPS_KEY_MAILER_PATH"/needs_terminal"
+#define DEFAULT_APPS_KEY_MAILER_EXEC       DEFAULT_APPS_KEY_MAILER_PATH"/command"
+
+#define DEFAULT_APPS_KEY_TERMINAL_PATH "/desktop/gnome/applications/terminal"
+#define DEFAULT_APPS_KEY_TERMINAL_EXEC_ARG DEFAULT_APPS_KEY_TERMINAL_PATH"/exec_arg"
+#define DEFAULT_APPS_KEY_TERMINAL_EXEC DEFAULT_APPS_KEY_TERMINAL_PATH"/exec"
 
 #define MIME_APPLICATION_ID "gnome-default-applications-editor"
 
 typedef struct _BrowserDescription BrowserDescription;
-typedef struct _HelpViewDescription HelpViewDescription;
+typedef struct _MailerDescription MailerDescription;
 typedef struct _TerminalDesciption TerminalDescription;
 
 /* All defined below */
@@ -76,7 +79,7 @@ on_text_custom_properties_clicked (GtkWidget *w, GladeXML *dialog)
 	mime_app = gnome_vfs_application_registry_get_mime_application (MIME_APPLICATION_ID);
 
 	gtk_entry_set_text (GTK_ENTRY (WID ("text_custom_name_entry")),
-			    mime_app ? mime_app->name : "");
+			    mime_app ? _(mime_app->name) : "");
 	gtk_entry_set_text (GTK_ENTRY (WID ("text_custom_command_entry")),
 			    mime_app ? mime_app->command : "");
 	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (WID ("text_custom_multi_toggle")),
@@ -159,6 +162,8 @@ on_text_default_viewer_toggle (GtkWidget *toggle, GladeXML *dialog)
 static void
 generic_guard (GtkWidget *toggle, GtkWidget *widget)
 {
+
+	gtk_toggle_button_set_inconsistent (GTK_TOGGLE_BUTTON (toggle), FALSE);
 	gtk_widget_set_sensitive (widget, GTK_TOGGLE_BUTTON (toggle)->active);
 
 	if (GTK_TOGGLE_BUTTON (toggle)->active) {
@@ -181,20 +186,46 @@ static void
 initialize_default_applications (void)
 {
         gint i;
+	/* This is used to only have one Evolution entry in the dropdown box
+	 * in case the user has installed both evo for gnome1 and for gnome2
+	 */
+	gboolean evo_already_in_list = FALSE;
 
 	text_editors = gnome_vfs_mime_get_all_applications ("text/plain");
 
         for (i = 0; i < G_N_ELEMENTS (possible_browsers); i++ ) {
-                if (g_find_program_in_path (possible_browsers[i].executable_name))
+		gchar *browsers = g_find_program_in_path (possible_browsers[i].executable_name);
+                if (browsers) {
 			possible_browsers[i].in_path = TRUE;
+			g_free(browsers);
+		}
         }
-        for (i = 0; i < G_N_ELEMENTS (possible_help_viewers); i++ ) {
-                if (g_find_program_in_path (possible_help_viewers[i].executable_name))
-			possible_help_viewers[i].in_path = TRUE;
+        for (i = 0; i < G_N_ELEMENTS (possible_mailers); i++ ) {	  
+		gchar *mailers;
+		gchar *exec_name = possible_mailers[i].executable_name;
+
+		mailers =  g_find_program_in_path (exec_name);
+                if (mailers) {
+			if (g_str_has_prefix (exec_name, "evolution")) {
+				if (evo_already_in_list) {
+					g_free (mailers);
+					continue;
+				} else {
+					evo_already_in_list = TRUE;
+				}
+			}
+
+			possible_mailers[i].in_path = TRUE;
+			g_free(mailers);
+		}
         }
+
         for (i = 0; i < G_N_ELEMENTS (possible_terminals); i++ ) {
-                if (g_find_program_in_path (possible_terminals[i].exec))
+                gchar *terminals = g_find_program_in_path (possible_terminals[i].exec);
+		if (terminals) {
 			possible_terminals[i].in_path = TRUE;
+			g_free (terminals);
+		}
         }
 }
 
@@ -227,9 +258,10 @@ read_editor (GConfClient *client,
 
 		if (strcmp (mime_app->command, li_app->command) == 0 &&
 		    mime_app->requires_terminal == li_app->requires_terminal) {
-			gtk_entry_set_text (GTK_ENTRY (WID ("text_select_combo_entry")), mime_app->name);
+			gtk_entry_set_text (GTK_ENTRY (WID ("text_select_combo_entry")), _(mime_app->name));
 			gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (WID ("text_custom_radio")), TRUE);
 			gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (WID ("text_select_radio")), TRUE);
+			gnome_vfs_mime_application_free (mime_app);
 			return;
 		}
         }
@@ -245,13 +277,13 @@ read_editor (GConfClient *client,
 	gnome_vfs_application_registry_save_mime_application (mime_app);
 
 	gnome_vfs_mime_set_default_application ("text/plain", mime_app->id);
-	gnome_vfs_mime_application_free (mime_app);
-
 	gnome_vfs_application_registry_sync ();	
 
  read_editor_custom:
 	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (WID ("text_select_radio")), TRUE);
 	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (WID ("text_custom_radio")), TRUE);
+	if (mime_app)
+		gnome_vfs_mime_application_free (mime_app);
 }
 
 static void
@@ -323,12 +355,10 @@ setup_peditors (GConfClient *client,
 	gconf_peditor_new_string  (changeset, DEFAULT_APPS_KEY_BROWSER_EXEC,
 				   WID ("web_custom_command_entry"), NULL);
 
-	gconf_peditor_new_boolean (changeset, DEFAULT_APPS_KEY_HELP_VIEWER_NEEDS_TERM,
-				   WID ("help_custom_terminal_toggle"), NULL);
-	gconf_peditor_new_boolean (changeset, DEFAULT_APPS_KEY_HELP_VIEWER_ACCEPTS_URLS,
-				   WID ("help_custom_url_toggle"), NULL);
-	gconf_peditor_new_string  (changeset, DEFAULT_APPS_KEY_HELP_VIEWER_EXEC,
-				   WID ("help_custom_command_entry"), NULL);
+	gconf_peditor_new_boolean (changeset, DEFAULT_APPS_KEY_MAILER_NEEDS_TERM,
+				   WID ("mail_custom_terminal_toggle"), NULL);
+	gconf_peditor_new_string  (changeset, DEFAULT_APPS_KEY_MAILER_EXEC,
+				   WID ("mail_custom_command_entry"), NULL);
 
 	gconf_peditor_new_string  (changeset, DEFAULT_APPS_KEY_TERMINAL_EXEC,
 				   WID ("terminal_custom_command_entry"), NULL);
@@ -369,9 +399,47 @@ read_browser (GConfClient *client,
 			return;
 		}
         }
-	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (WID ("web_select_radio")), TRUE);
-	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (WID ("web_custom_radio")), TRUE);
+	gtk_toggle_button_set_inconsistent (GTK_TOGGLE_BUTTON (WID ("web_select_radio")), TRUE);
+	gtk_toggle_button_set_inconsistent (GTK_TOGGLE_BUTTON (WID ("web_custom_radio")), TRUE);
 	g_free (browser);
+}
+
+static void
+read_mailer (GConfClient *client,
+	     GladeXML    *dialog)
+{
+	GError *error = NULL;
+	gchar *mailer;
+	gboolean needs_term;
+	gint i;
+
+	needs_term = gconf_client_get_bool (client, DEFAULT_APPS_KEY_MAILER_NEEDS_TERM, &error);
+	if (error) {
+		/* hp will shoot me -- I'll do this later. */
+		return;
+	}
+	mailer = gconf_client_get_string (client, DEFAULT_APPS_KEY_MAILER_EXEC, &error);
+	if (error) {
+		return;
+	}
+
+	for (i = 0; i < G_N_ELEMENTS (possible_mailers); i++ ) {
+		if (possible_mailers[i].in_path == FALSE)
+			continue;
+		
+		if (mailer && strcmp (mailer, possible_mailers[i].command) == 0 &&
+		    needs_term == possible_mailers[i].needs_term) {
+			gtk_entry_set_text (GTK_ENTRY (WID ("mail_select_combo_entry")),
+					    _(possible_mailers[i].name));
+			gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (WID ("mail_custom_radio")), TRUE);
+			gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (WID ("mail_select_radio")), TRUE);
+			g_free (mailer);
+			return;
+		}
+        }
+	gtk_toggle_button_set_inconsistent (GTK_TOGGLE_BUTTON (WID ("mail_select_radio")), TRUE);
+	gtk_toggle_button_set_inconsistent (GTK_TOGGLE_BUTTON (WID ("mail_custom_radio")), TRUE);
+	g_free (mailer);
 
 	
 }
@@ -394,70 +462,19 @@ browser_setup_custom (GtkWidget *entry,
 	}
 }
 
-
 static void
-read_help_viewer (GConfClient *client,
-	     GladeXML    *dialog)
-{
-	GError *error = NULL;
-	gchar *help_viewer;
-	gboolean needs_term;
-	gboolean accepts_urls;
-	gint i;
-
-	needs_term = gconf_client_get_bool (client, DEFAULT_APPS_KEY_HELP_VIEWER_NEEDS_TERM, &error);
-	if (error) {
-		/* hp will shoot me -- I'll do this later. */
-		return;
-	}
-	accepts_urls = gconf_client_get_bool (client, DEFAULT_APPS_KEY_HELP_VIEWER_ACCEPTS_URLS, &error);
-	if (error) {
-		return;
-	}
-	help_viewer = gconf_client_get_string (client, DEFAULT_APPS_KEY_HELP_VIEWER_EXEC, &error);
-	if (error) {
-		return;
-	}
-
-	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (WID ("help_custom_terminal_toggle")), needs_term);
-	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (WID ("help_custom_url_toggle")), accepts_urls);
-	gtk_entry_set_text (GTK_ENTRY (WID ("help_custom_command_entry")), help_viewer);
-
-	for (i = 0; i < G_N_ELEMENTS (possible_help_viewers); i++ ) {
-		if (possible_help_viewers[i].in_path == FALSE)
-			continue;
-		
-		if (help_viewer && strcmp (help_viewer, possible_help_viewers[i].executable_name) == 0 &&
-		    needs_term == possible_help_viewers[i].needs_term &&
-		    accepts_urls == possible_help_viewers[i].accepts_urls) {
-			gtk_entry_set_text (GTK_ENTRY (WID ("help_select_combo_entry")),
-					    _(possible_help_viewers[i].name));
-			gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (WID ("help_custom_radio")), TRUE);
-			gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (WID ("help_select_radio")), TRUE);
-			g_free (help_viewer);
-			return;
-		}
-        }
-	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (WID ("help_select_radio")), TRUE);
-	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (WID ("help_custom_radio")), TRUE);
-	g_free (help_viewer);
-}
-
-static void
-help_setup_custom (GtkWidget *entry,
-		   GladeXML  *dialog)
+mailer_setup_custom (GtkWidget *entry,
+		     GladeXML  *dialog)
 {
 	gint i;
-	const gchar *help_viewer = gtk_entry_get_text (GTK_ENTRY (entry));
+	const gchar *mailer = gtk_entry_get_text (GTK_ENTRY (entry));
 
-	for (i = 0; i < G_N_ELEMENTS (possible_help_viewers); i++ ) {
-		if (! strcmp (_(possible_help_viewers[i].name), help_viewer)) {
-			gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (WID ("help_custom_terminal_toggle")),
-						      possible_help_viewers[i].needs_term);
-			gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (WID ("help_custom_url_toggle")),
-						      possible_help_viewers[i].accepts_urls);
-			gtk_entry_set_text (GTK_ENTRY (WID ("help_custom_command_entry")),
-					    possible_help_viewers[i].executable_name);
+	for (i = 0; i < G_N_ELEMENTS (possible_mailers); i++ ) {
+		if (! strcmp (_(possible_mailers[i].name), mailer)) {
+		        gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (WID ("mail_custom_terminal_toggle")),
+						      possible_mailers[i].needs_term);
+			gtk_entry_set_text (GTK_ENTRY (WID ("mail_custom_command_entry")),
+					    possible_mailers[i].command);
 			return;
 		}
 	}
@@ -495,6 +512,8 @@ read_terminal (GConfClient *client,
 					    _(possible_terminals[i].name));
 			gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (WID ("terminal_custom_radio")), TRUE);
 			gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (WID ("terminal_select_radio")), TRUE);
+			g_free (exec);
+			g_free (exec_arg);
 			return;
 		}
         }
@@ -527,11 +546,10 @@ value_changed_cb (GConfClient *client,
 		  GladeXML    *dialog)
 {
 	g_return_if_fail (key != NULL);
-
-	if (strncmp (key, "/desktop/gnome/applications/editor", strlen ("/desktop/gnome/applications/editor")) == 0) {
-	} else if (strncmp (key, "/desktop/gnome/applications/browser/exec", strlen ("/desktop/gnome/applications/browser/exec")) == 0) {
-	} else if (strncmp (key, "/desktop/gnome/applications/help_viewer", strlen ("/desktop/gnome/applications/help_viewer")) == 0) {
-	} else if (strncmp (key, "/desktop/gnome/applications/terminal", strlen ("/desktop/gnome/applications/terminal")) == 0) {
+	if (strncmp (key, DEFAULT_APPS_KEY_MAILER_PATH, strlen (DEFAULT_APPS_KEY_MAILER_PATH)) == 0) {
+		gconf_client_set_bool (client, DEFAULT_APPS_KEY_MAILER_PATH"/enabled", TRUE, NULL);
+	} else if (strncmp (key, DEFAULT_APPS_KEY_BROWSER_PATH, strlen (DEFAULT_APPS_KEY_BROWSER_PATH)) == 0) {
+	} else if (strncmp (key, DEFAULT_APPS_KEY_TERMINAL_PATH, strlen (DEFAULT_APPS_KEY_TERMINAL_PATH)) == 0) {
 	}
 }
 
@@ -541,9 +559,7 @@ dialog_response (GtkDialog *widget,
 		 GladeXML  *dialog)
 {
 	if (response_id == GTK_RESPONSE_HELP)
-		capplet_help (GTK_WINDOW (widget),
-			"wgoscustlookandfeel.xml",
-			"goscustdoc-2");
+		capplet_help (GTK_WINDOW (widget), "wgoscustlookandfeel.xml", "goscustdoc-2");
 	else
 		gtk_main_quit ();
 }
@@ -555,12 +571,13 @@ create_dialog (GConfClient *client)
 	GList *strings = NULL, *li;
 	gint i;
 	dialog = glade_xml_new (GNOMECC_DATA_DIR "/interfaces/gnome-default-applications-properties.glade", NULL, NULL);
+	capplet_set_icon (WID ("default_applications_dialog"), "default-applications-capplet.png");
 	
 	setup_peditors (client, dialog);
 
 	/* Editors page */
 	for (li = text_editors; li; li = li->next) {
-		strings = g_list_append (strings, ((GnomeVFSMimeApplication *)li->data)->name);
+		strings = g_list_append (strings, _(((GnomeVFSMimeApplication *)li->data)->name));
 	}
 	if (strings) {
 		/* We have default editors */
@@ -613,45 +630,46 @@ create_dialog (GConfClient *client)
 			  "changed", (GCallback) browser_setup_custom,
 			  dialog);
 	g_signal_connect (G_OBJECT (WID ("web_select_radio")),
-			  "toggled", (GCallback) generic_guard,
+			  "clicked", (GCallback) generic_guard,
 			  WID ("web_select_combo"));
 	g_signal_connect (G_OBJECT (WID ("web_custom_radio")),
-			  "toggled", (GCallback) generic_guard,
+			  "clicked", (GCallback) generic_guard,
 			  WID ("web_custom_vbox"));
 
 	read_browser (client, dialog);
 
-	/* Help page */
-	
-	for (i = 0; i < G_N_ELEMENTS (possible_help_viewers); i++ ) {
-		if (possible_help_viewers[i].in_path)
-			strings = g_list_append (strings, _(possible_help_viewers[i].name));
+
+	/* Mail readers page */
+	for (i = 0; i < G_N_ELEMENTS (possible_mailers); i++ ) {
+		if (possible_mailers[i].in_path)
+			strings = g_list_append (strings, _(possible_mailers[i].name));
 	}
 	if (strings) {
-		/* We have default help viewers */
-		gtk_combo_set_popdown_strings (GTK_COMBO(WID ("help_select_combo")), strings);
+		/* We have default browsers */
+		gtk_combo_set_popdown_strings (GTK_COMBO(WID ("mail_select_combo")), strings);
 		g_list_free (strings);
 		strings = NULL;
 	} else {
-		/* No default help viewers */
-		gtk_widget_set_sensitive (WID ("help_select_radio"), FALSE);
+		/* No default browsers */
+		gtk_widget_set_sensitive (WID ("mail_select_radio"), FALSE);
 	}
 
 	/* Source of command string */
-	g_object_set_data (G_OBJECT (WID ("help_select_radio")), "entry", WID ("help_select_combo_entry"));
+	g_object_set_data (G_OBJECT (WID ("mail_select_radio")), "entry", WID ("mail_select_combo_entry"));
 	/* Source of command string */
-	g_object_set_data (G_OBJECT (WID ("help_custom_radio")), "entry", WID ("help_custom_command_entry"));
+	g_object_set_data (G_OBJECT (WID ("mail_custom_radio")), "entry", WID ("mail_custom_command_entry"));
 
-	g_signal_connect (G_OBJECT (WID ("help_select_combo_entry")),
-			  "changed", (GCallback) help_setup_custom,
+	g_signal_connect (G_OBJECT (WID ("mail_select_combo_entry")),
+			  "changed", (GCallback) mailer_setup_custom,
 			  dialog);
-	g_signal_connect (G_OBJECT (WID ("help_select_radio")),
-			  "toggled", (GCallback) generic_guard,
-			  WID ("help_select_combo"));
-	g_signal_connect (G_OBJECT (WID ("help_custom_radio")),
-			  "toggled", (GCallback) generic_guard,
-			  WID ("help_custom_vbox"));
-	read_help_viewer (client, dialog);	
+	g_signal_connect (G_OBJECT (WID ("mail_select_radio")),
+			  "clicked", (GCallback) generic_guard,
+			  WID ("mail_select_combo"));
+	g_signal_connect (G_OBJECT (WID ("mail_custom_radio")),
+			  "clicked", (GCallback) generic_guard,
+			  WID ("mail_custom_vbox"));
+
+	read_mailer (client, dialog);
 
 
 	/* Terminal */
@@ -726,7 +744,6 @@ main (int argc, char **argv)
 	client = gconf_client_get_default ();
 
 	gconf_client_add_dir (client, "/desktop/gnome/applications/browser", GCONF_CLIENT_PRELOAD_ONELEVEL, NULL);
-	gconf_client_add_dir (client, "/desktop/gnome/applications/help_viewer", GCONF_CLIENT_PRELOAD_ONELEVEL, NULL);
 	gconf_client_add_dir (client, "/desktop/gnome/applications/terminal", GCONF_CLIENT_PRELOAD_ONELEVEL, NULL);
 
 	if (get_legacy) {
